@@ -7,4 +7,4 @@ def argument_parser(subparsers):
 
 
 def show(project):
-    print json.dumps(project.context, indent=2)
+    print(json.dumps(project.context, indent=2))
