@@ -108,13 +108,13 @@ class Container(object):
         self.docker.push(self.repository)
 
     def load_credentials(self, renew=False):
-        cfg = load_config().get('Configs', {}).get(self.project.docker_registry_url, None)
+        cfg = load_config().get(self.project.docker_registry_url, None)
         if renew or not cfg:
             self._user, self._token = login(self.project)
             store_credentials(self.project.docker_registry_url, self._user, self._token)
         else:
-            self._user = cfg['Username']
-            self._token = cfg['Password']
+            self._user = cfg['username']
+            self._token = cfg['password']
 
     @property
     def tag(self):
