@@ -50,17 +50,14 @@ class Adun(Executor):
         job_dir = job.job_id
         os.mkdir(job_dir)
         os.chmod(job_dir, os.stat(job_dir).st_mode | stat.S_IROTH | stat.S_IWOTH | stat.S_IXOTH)
-        os.chdir(job_dir)
-        with open('__in__.json', 'w') as fp:
-            logging.debug('Writing job order to %s', os.path.abspath('__in__.json'))
+        in_file, out_file = [os.path.join(job_dir, f) for f in '__in__.json', '__out__.json']
+        with open(in_file, 'w') as fp:
+            logging.debug('Writing job order to %s', in_file)
             to_json(job, fp)
-        self.runner.run_job('__in__.json',
-                            '__out__.json',
-                            cwd=job_dir)
-        with open('__out__.json') as fp:
-            logging.debug('Reading job output from %s', os.path.abspath('__out__.json'))
+        self.runner.run_job('__in__.json', '__out__.json', cwd=job_dir)
+        with open(out_file) as fp:
+            logging.debug('Reading job output from %s', out_file)
             result = from_json(fp)
-        os.chdir('..')
         from subprocess import Popen
         Popen(['sudo chmod -R 777 ' + job_dir], shell=True)  # TODO: remove
         Popen(['sudo chown -R 1001:1001 ' + job_dir], shell=True)  # TODO: remove
