@@ -106,13 +106,13 @@ def run_script():
     try:
         args['cmd_func'](**args)
     except ProtocolException as e:
-        logging.exception("Bad Input: %s", args)
+        logging.exception("Bad Job: %s", args)
         return exit_code_for_exception(e)
     except ValidationException as e:
-        logging.exception("Input or Params Validation Failed: %s", args)
+        logging.exception("Input or params validation failed: %s", args)
         return exit_code_for_exception(e)
     except JobException as e:
-        logging.exception("Command failed: %s", args)
+        logging.exception("Wrapper error: %s", args)
         return exit_code_for_exception(e)
     except Exception:
         logging.exception("Internal error: %s", args)
